%define with_Cg         0
%if %with_Cg
%define real_name       OpenEXR_Viewers-nonfree
%define V_suffix        -nonfree
%define priority        10
%else
%define real_name       OpenEXR_Viewers
%define V_suffix        -fedora
%define priority        5
%endif

%global project openexr

Name:           %{real_name}
Version:        2.3.0
Release:    1%{?dist}
Summary:        Viewers programs for OpenEXR

License:        AMPAS BSD
URL:            http://www.openexr.com
Source0: https://github.com/%{project}/%{project}/releases/download/v%{version}/OpenEXR_Viewers-%{version}.tar.gz

Patch1: openexr_viewers-2.0.1-dso.patch
Patch2: openexr_viewers-gcc-11-fixes.patch
Patch3: openexr_viewers-imfheader.patch

BuildRequires:  make
BuildRequires:  libtool
BuildRequires:  gcc-c++

BuildRequires:  fltk-devel >= 1.1
BuildRequires:  pkgconfig(OpenEXR) >= 2.1
%if %with_Cg
BuildRequires:  Cg
BuildRequires:  freeglut-devel
Provides: OpenEXR_Viewers = %{version}
%else
BuildConflicts:  Cg
%endif

%if 0%{?openexr_ctl}
BuildRequires:  pkgconfig(OpenEXR_CTL)
BuildRequires:  OpenEXR_CTL
Requires:  OpenEXR_CTL
%endif
Requires(post): /usr/sbin/alternatives
Requires(preun): /usr/sbin/alternatives


%description
exrdisplay is a simple still image viewer that optionally applies color
transforms to OpenEXR images, using ctl as explained in this document:
doc/OpenEXRViewers.pdf

%if %with_Cg
playexr is a program that plays back OpenEXR image sequences, optionally
with CTL support, applying rendering and display transforms in line with
the current discussions at the AMPAS Image Interchange Framework committee
(September 2006).

This is the nonfree version compiled with NVIDIA Cg support
See: https://developer.nvidia.com/cg-toolkit
%else

%package docs
Summary:        Documentation for %{name}

%description docs
This package contains documentation files for %{name}.
%endif

%prep
%setup -q -n openexr_viewers-%{version}

%patch1 -p1 -b .dso
%patch2 -p1 -b .gcc11
%patch3 -p1 -b .imfh

%if "%{_lib}" == "lib64"
sed -i -e 's|ACTUAL_PREFIX/lib/CTL|ACTUAL_PREFIX/lib64/CTL|' configure.ac
%endif
./bootstrap
sed -i -e 's|#include <vector>\n    using namespace Ctl|#include <vector>\n    #include <cstdlib>\nusing namespace Ctl|' configure


%build
export CXXFLAGS="$RPM_OPT_FLAGS -L%{_libdir}"
%configure  --disable-static \
  --disable-openexrtest \
  --disable-openexrctltest \
%if %with_Cg
  --with-cg-prefix=%{_prefix}
%endif

sed -i -e 's|LIBS =|LIBS = -lglut|' playexr/Makefile

%make_build


%install
%make_install

rm -rf %{buildroot}%{_includedir}

mv %{buildroot}%{_bindir}/exrdisplay %{buildroot}%{_bindir}/exrdisplay%{V_suffix}

rm -rf %{buildroot}%{_datadir}/doc

touch %{buildroot}%{_bindir}/exrdisplay

%post
alternatives --install %{_bindir}/exrdisplay exrdisplay %{_bindir}/exrdisplay%{V_suffix} %{priority} ||:


%preun
if [ $1 -eq 0 ]; then
  alternatives --remove exrdisplay %{_bindir}/exrdisplay%{V_suffix} || :
fi

%files
%doc ChangeLog README.md
%license LICENSE
%ghost %{_bindir}/exrdisplay
%{_bindir}/exrdisplay%{V_suffix}
%if %with_Cg
%{_bindir}/playexr
%else

%files docs
%doc doc/OpenEXRViewers.odt doc/OpenEXRViewers.pdf
%endif

%changelog
* Fri Apr 12 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.3.0-1
- initial build
